@@ -37,6 +37,7 @@ from .controltower import ControlTower
 from .billing import Billing
 from .sso import Sso
 from .cloudformation import Cloudformation
+from .console import AccountManager, PasswordManager
 
 __author__ = '''Costas Tyfoxylos <ctyfoxylos@schubergphilis.com>'''
 __docformat__ = '''google'''
@@ -56,3 +57,5 @@ assert ControlTower
 assert Billing
 assert Sso
 assert Cloudformation
+assert AccountManager
+assert PasswordManager
