@@ -38,14 +38,18 @@ import logging
 import time
 from functools import wraps
 from time import sleep
+from typing import Optional
 
 import boto3
 import botocore
 import requests
-
+from boto3_type_annotations.organizations import Client as OrganizationsClient
+from boto3_type_annotations.servicecatalog import Client as ServicecatalogClient
+from cachetools import cached
+from cachetools import TTLCache
 from opnieuw import retry
-from awsapilib.authentication import Authenticator, LoggerMixin
 
+from awsapilib.authentication import Authenticator, LoggerMixin
 from .controltowerexceptions import (UnsupportedTarget,
                                      OUCreating,
                                      NoServiceCatalogAccess,
@@ -56,7 +60,8 @@ from .controltowerexceptions import (UnsupportedTarget,
                                      EmailCheckFailed,
                                      EmailInUse,
                                      UnavailableRegion,
-                                     RoleCreationFailure)
+                                     RoleCreationFailure,
+                                     NoActiveArtifactRetrieved)
 from .resources import (LOGGER,
                         LOGGER_BASENAME,
                         ServiceControlPolicy,
@@ -129,8 +134,10 @@ class ControlTower(LoggerMixin):  # pylint: disable=too-many-instance-attributes
 
     def __init__(self, arn, settling_time=90, region=None):
         self.aws_authenticator = Authenticator(arn, region=region)
-        self.service_catalog = boto3.client('servicecatalog', **self.aws_authenticator.assumed_role_credentials)
-        self.organizations = boto3.client('organizations', **self.aws_authenticator.assumed_role_credentials)
+        self.service_catalog: ServicecatalogClient = boto3.client('servicecatalog',
+                                                                  **self.aws_authenticator.assumed_role_credentials)
+        self.organizations: OrganizationsClient = boto3.client('organizations',
+                                                               **self.aws_authenticator.assumed_role_credentials)
         self.session = self._get_authenticated_session()
         self._region = region
         self._is_deployed = None
@@ -143,6 +150,7 @@ class ControlTower(LoggerMixin):  # pylint: disable=too-many-instance-attributes
 
     @property
     def _account_factory(self):
+        """The AccountFactory object."""
         if any([not self.is_deployed,
                 self.percentage_complete != 100]):
             return None
@@ -241,11 +249,24 @@ class ControlTower(LoggerMixin):  # pylint: disable=too-many-instance-attributes
         return self.aws_authenticator.get_control_tower_authenticated_session()
 
     @property
+    def active_artifact_id(self) -> str:
+        """Contains the id of the active artifact.
+
+        Returns:
+            str with the artifact id or an empty string
+
+        """
+        return self._active_artifact.get('Id', '')
+
+    @property
+    @cached(cache=TTLCache(maxsize=1, ttl=20))
     def _active_artifact(self):
         artifacts = self.service_catalog.list_provisioning_artifacts(ProductId=self._account_factory.product_id)
-        return next((artifact for artifact in artifacts.get('ProvisioningArtifactDetails', [])
-                     if artifact.get('Active')),
-                    None)
+        try:
+            return next((artifact for artifact in artifacts.get('ProvisioningArtifactDetails', [])
+                         if artifact.get('Active')))
+        except StopIteration:
+            raise NoActiveArtifactRetrieved('Could not retrieve the active artifact from service catalog.')
 
     @staticmethod
     def _get_account_factory(service_catalog_client):
@@ -263,13 +284,15 @@ class ControlTower(LoggerMixin):  # pylint: disable=too-many-instance-attributes
             raise UnsupportedTarget(target)
         return target
 
-    def _get_api_payload(self,  # pylint: disable=too-many-arguments
-                         content_string,
-                         target,
-                         method='POST',
-                         params=None,
-                         path=None,
-                         region=None):
+    def _get_api_payload(self,
+                         *,
+                         content_string: str,
+                         target: str,
+                         method: str = 'POST',
+                         params: Optional[dict] = None,
+                         path: Optional[str] = None,
+                         region: Optional[str] = None) -> dict:
+        """Constructs the API payload."""
         target = self._validate_target(target)
         payload = {'contentString': json.dumps(content_string),
                    'headers': {'Content-Type': self.api_content_type,
@@ -282,7 +305,8 @@ class ControlTower(LoggerMixin):  # pylint: disable=too-many-instance-attributes
                    'region': region or self.region}
         return copy.deepcopy(payload)
 
-    def _get_paginated_results(self,  # pylint: disable=too-many-arguments
+    def _get_paginated_results(self,
+                               *,
                                content_payload,
                                target,
                                object_group=None,
@@ -388,17 +412,18 @@ class ControlTower(LoggerMixin):  # pylint: disable=too-many-instance-attributes
                                            next_token_marker='NextToken')
 
     @validate_availability
-    def register_organizations_ou(self, name):
+    def register_organizations_ou(self, name: str, force: bool = False) -> bool:
         """Registers an Organizations OU under control tower.
 
         Args:
             name (str): The name of the Organizations OU to register to Control Tower.
+            force (bool): Forces re-registering if the OU is already controlled by Control Tower
 
         Returns:
-            result (bool): True if successfull, False otherwise.
+            result (bool): True if successful, False otherwise.
 
         """
-        if self.get_organizational_unit_by_name(name):
+        if self.get_organizational_unit_by_name(name) and not force:
             self.logger.info('OU "%s" is already registered with Control Tower.', name)
             return True
         org_ou = self.get_organizations_ou_by_name(name)
@@ -415,7 +440,7 @@ class ControlTower(LoggerMixin):  # pylint: disable=too-many-instance-attributes
             name (str): The name of the OU to create.
 
         Returns:
-            result (bool): True if successfull, False otherwise.
+            result (bool): True if successful, False otherwise.
 
         """
         self.logger.debug('Trying to create OU :"%s" under root ou', name)
@@ -434,7 +459,7 @@ class ControlTower(LoggerMixin):  # pylint: disable=too-many-instance-attributes
         return self._register_org_ou_in_control_tower(org_ou)
 
     def _register_org_ou_in_control_tower(self, org_ou):
-        self.logger.debug('Trying to move management of OU under Control Tower')
+        self.logger.debug('Registering or re-registering OU under Control Tower')
         payload = self._get_api_payload(content_string={'OrganizationalUnitId': org_ou.id,
                                                         'OrganizationalUnitName': org_ou.name},
                                         target='manageOrganizationalUnit')
@@ -444,7 +469,7 @@ class ControlTower(LoggerMixin):  # pylint: disable=too-many-instance-attributes
                               'and response text "%s"',
                               org_ou.name, response.status_code, response.text)
             return False
-        self.logger.debug('Successfully moved management of OU "%s" under Control Tower', org_ou.name)
+        self.logger.debug('Successfully registered or re-registered OU "%s" under Control Tower', org_ou.name)
         return True
 
     def _is_busy_with_ou_guardrails(self):
@@ -468,7 +493,7 @@ class ControlTower(LoggerMixin):  # pylint: disable=too-many-instance-attributes
             name (str): The name of the OU to delete.
 
         Returns:
-            result (bool): True if successfull, False otherwise.
+            result (bool): True if successful, False otherwise.
 
         """
         organizational_unit = self.get_organizational_unit_by_name(name)
@@ -1044,15 +1069,15 @@ class ControlTower(LoggerMixin):  # pylint: disable=too-many-instance-attributes
         return self._create_system_role(parameters)
 
     def deploy(self,  # pylint: disable=too-many-arguments,too-many-locals
-               logging_account_email,
-               security_account_email,
-               logging_account_name='Log Archive',
-               security_account_name='Audit',
-               core_ou_name='Security',
-               custom_ou_name='Sandbox',
-               regions=None,
-               retries=10,
-               wait=1):
+               logging_account_email: str,
+               security_account_email: str,
+               logging_account_name: str = 'Log Archive',
+               security_account_name: str = 'Audit',
+               core_ou_name: str = 'Security',
+               custom_ou_name: str = 'Sandbox',
+               regions: Optional[list] = None,
+               retries: int = 10,
+               wait: int = 1) -> bool:
         """Deploys control tower.
 
         Returns:
@@ -1102,11 +1127,11 @@ class ControlTower(LoggerMixin):  # pylint: disable=too-many-instance-attributes
         self.logger.debug('Trying to deploy control tower with payload "%s"', payload)
         return self._deploy(payload, retries, wait)
 
-    def _deploy(self, payload, retries=10, wait=1):
-        succeded = False
+    def _deploy(self, payload: dict, retries: int = 10, wait: int = 1) -> bool:
+        succeeded = False
         while retries:
             response = self.session.post(self.url, json=payload)
-            succeded = response.ok
+            succeeded = response.ok
             retries -= 1
             if response.ok:
                 retries = 0
@@ -1116,7 +1141,7 @@ class ControlTower(LoggerMixin):  # pylint: disable=too-many-instance-attributes
                                   'still have %s retries will wait for %s seconds', response.status_code,
                                   response.text, retries, wait)
                 sleep(wait)
-        if not succeded:
+        if not succeeded:
             self.logger.error('Failed to deploy control tower, retries were spent.. Maybe try again later?')
             return False
         self.logger.debug('Successfully started deploying control tower.')
@@ -1126,10 +1151,10 @@ class ControlTower(LoggerMixin):  # pylint: disable=too-many-instance-attributes
             time.sleep(1)
         return True
 
-    def decommission(self):
+    def decommission(self) -> bool:
         """Decommissions a landing zone.
 
-        The api call does not seem to be enough and although the resources are decomissioned like with
+        The api call does not seem to be enough and although the resources are decommissioned like with
         the proper process, control tower responds with a delete failed on the api, so it seems that
         aws needs to perform actions on their end for the decommissioning to be successful.
 
